diff --git a/tools/change-chart-version.sh b/tools/change-chart-version.sh
index 07637cc2b1a3624c6ede4ec1a48b3ab579b93484..358cd7412ee54a96920e7df72dd4751b29cf58b7 100755
--- a/tools/change-chart-version.sh
+++ b/tools/change-chart-version.sh
@@ -13,30 +13,33 @@
 #   limitations under the License.
 #
 
-if [ "$#" -ne 2]; then
+if [ "$#" -ne 2 ]; then
   echo "Usage: $0 <NEW_VERSION> <USER>"
-  echo "Exapmle: $0 v16.0.0 garciadeblas"
-  echo "Exapmle: $0 v15.0.7 vegall"
+  echo "Example: $0 16.0.0 garciadeblas"
+  echo "Example: $0 15.0.7 vegall"
   exit 1
 fi
 
 NEW_VERSION="$1"
 USER="$2"
 REPO_URL="ssh://$USER@osm.etsi.org:29418/osm/devops"
-# If the $NEW_VERSION == v15.0.1, the $BRANCH_NAME will be v15.0
-BRANCH_NAME=$(echo $NEW_VERSION | grep -oE 'v[0-9]+\.[0-9]+')
+# If the $NEW_VERSION == 15.0.1, the $BRANCH_NAME will be v15.0
+BRANCH_NAME="v$(echo $NEW_VERSION | grep -oE '[0-9]+\.[0-9]+')"
 
-git clone $REPO_URL
-cd devops
+git clone $REPO_URL && (cd "devops" && curl https://osm.etsi.org/gerrit/tools/hooks/commit-msg > .git/hooks/commit-msg ; chmod +x .git/hooks/commit-msg)
+pushd devops
 
 git checkout $BRANCH_NAME
 
-sed -i -E "0,/^version: .*/s//version: $NEW_VERSION/" installers/osm/Chart.yaml
+sed -i -E "0,/^version: .*/s//version: \"$NEW_VERSION\"/" installers/helm/osm/Chart.yaml
 sed -i -E "0,/^appVersion: .*/s//appVersion: \"$NEW_VERSION\"/" installers/helm/osm/Chart.yaml
 
 git add installers/helm/osm/Chart.yaml
-git commit -m "Update chart version version to $NEW_VERSION"
+git commit -s -m "Update chart version version to $NEW_VERSION"
 git push origin $BRANCH_NAME
 
 commit=$(git show --summary | grep commit | awk '{print $2}')
-echo "The commit is $commit"
\ No newline at end of file
+echo "The commit is $commit"
+popd
+rm -rf devops
+